darkhistory.spec.transferfunction.TransFuncAtEnergy — DarkHistory documentation

# darkhistory.spec.transferfunction.TransFuncAtEnergy

class `darkhistory.spec.transferfunction.` `TransFuncAtEnergy`(spec_arr, eng=None, in_eng=None, rs=None, spec_type='dNdE', dlnz=-1, rebin_eng=None)

  Transfer function at a given injection energy.

  Collection of Spectrum objects, each at different redshifts.

  Parameters: | spec_arr : list of Spectrum List of Spectrum to be stored together. eng : ndarray, optional Energy abscissa. in_eng : ndarray, optional Injection energy abscissa. rs : ndarray, optional The redshift of the spectra. spec_type : {‘N’, ‘dNdE’}, optional Type of data stored, ‘dNdE’ is the default. dlnz : float The d ln(1+z) step for the transfer function. rebin_eng : ndarray, optional New abscissa to rebin all of the Spectrum objects into.
  Attributes: | in_eng : ndarray Array of injection energies corresponding to each spectrum. eng : ndarray Array of energy abscissa of each spectrum. rs : ndarray Array of redshifts corresponding to each spectrum. spec_type : {‘N’, ‘dNdE’} The type of values stored. dlnz : float The d ln(1+z) step for the transfer function.

  Methods

  `append`(spec) | Appends a new Spectrum.
  `at_rs`(new_rs[, interp_type, bounds_error, …]) | Interpolates the transfer function at a new redshift.
  `integrate_each_spec`([weight]) | Sums over each individual spectrum with some weight.
  `plot`(ax[, ind, step, indtype, fac]) | Plots the contained Spectrum objects.
  `rebin`(out_eng) | Re-bins all Spectrum objects according to a new abscissa.
  `redshift`(rs_arr) | Redshifts the stored spectra.
  `sum_specs`([weight]) | Sums the spectrum in each energy bin, weighted by weight.
  `switch_spec_type`([target]) | Switches between the type of values to be stored.
  `totN`([bound_type, bound_arr]) | Returns the total number of particles in part of the spectra.
  `toteng`([bound_type, bound_arr]) | Returns the total energy of particles in part of the spectra.

  `__init__`(spec_arr, eng=None, in_eng=None, rs=None, spec_type='dNdE', dlnz=-1, rebin_eng=None)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `__init__`(spec_arr[, eng, in_eng, rs, …]) | Initialize self.
  `append`(spec) | Appends a new Spectrum.
  `at_rs`(new_rs[, interp_type, bounds_error, …]) | Interpolates the transfer function at a new redshift.
  `integrate_each_spec`([weight]) | Sums over each individual spectrum with some weight.
  `plot`(ax[, ind, step, indtype, fac]) | Plots the contained Spectrum objects.
  `rebin`(out_eng) | Re-bins all Spectrum objects according to a new abscissa.
  `redshift`(rs_arr) | Redshifts the stored spectra.
  `sum_specs`([weight]) | Sums the spectrum in each energy bin, weighted by weight.
  `switch_spec_type`([target]) | Switches between the type of values to be stored.
  `totN`([bound_type, bound_arr]) | Returns the total number of particles in part of the spectra.
  `toteng`([bound_type, bound_arr]) | Returns the total energy of particles in part of the spectra.

  Attributes

  `N_underflow` |
  `eng` |
  `eng_underflow` |
  `grid_vals` |
  `in_eng` |
  `rs` |
  `spec_type` |

#### Previous topic

darkhistory.spec.transferfunction

#### Next topic

darkhistory.spec.transferfunction.TransFuncAtRedshift

### This Page

Show Source